@@ -33,7 +33,7 @@ __all__ = (
 DomainType = Literal["EFS", "S3"]
 EndpointTypeType = Literal["PUBLIC", "VPC", "VPC_ENDPOINT"]
 HomeDirectoryTypeType = Literal["LOGICAL", "PATH"]
-IdentityProviderTypeType = Literal["API_GATEWAY", "SERVICE_MANAGED"]
+IdentityProviderTypeType = Literal["API_GATEWAY", "AWS_DIRECTORY_SERVICE", "SERVICE_MANAGED"]
 ListServersPaginatorName = Literal["list_servers"]
 ProtocolType = Literal["FTP", "FTPS", "SFTP"]
 StateType = Literal["OFFLINE", "ONLINE", "STARTING", "START_FAILED", "STOPPING", "STOP_FAILED"]
